/* at.h --- definitions and the like for kat: Keith's at package */

/*

Copyright (c) 1990, W. Keith Pyle, Austin, Texas

*/

/* --- This section contains definitions which may need to be modified --- */
/* --- to conform to a given site --- */

/* Define the mailer that is used to send output to a user */
/* (Only one of the following should be uncommented) */

#define USE_SENDMAIL				/* /usr/lib/sendmail is used */
/*#define USE_BINMAIL					/* /bin/mail is used */
/*#define USE_UCBMAIL					/* /usr/ucb/Mail is used */

/* Define the maximum number of concurrent queued processes that can be run */
/* by atrun.  This definition is usually set in the Makefile, but define */
/* can be placed here.  If the value is set to 0, there is no limit. */

#ifndef MAXATPROC
#define MAXATPROC	16
#endif

/* --- The next section is typically only modified for a new port --- */

/* Define the characteristics of the system being used */

/* The system type is often available directly from cpp(1).  If not, */
/* define either GENERIC_BSD or GENERIC_SYSV as a first attempt. */
/* Then, modify the section below to work automagically, if possible. */

#if !defined(GENERIC_BSD) && !defined(GENERIC_SYSV)

#ifdef hpux
#define GENERIC_SYSV
#endif

#ifdef sequent
/* This assumes a BSD universe Sequent */
#define GENERIC_BSD
#define HAS_SYSLOGFACILTY
#else
/* All other 386 systems assumed to be System V */
#ifdef i386
#define GENERIC_SYSV
#endif
#endif

#ifdef sun
/* Dual personalities */
#define GENERIC_BSD
#define GENERIC_SYSV
#endif

#ifdef ultrix
#define GENERIC_BSD
#endif

#endif	/* Neither GENERIC_BSD or GENERIC_SYSV already defined */

#ifdef GENERIC_BSD
#define HAS_RINDEX
#define HAS_TIOCNOTTY
#endif

#ifdef GENERIC_SYSV
#define HAS_DIRENT
#define HAS_GETCWD
#define HAS_SYSLOGFACILTY
#define HAS_TERMIO
#endif

/* Files used by at */

#define SEQUENCE	".seq"			/* Contains job sequence number */
#define ALLOW_FILE	"at.allow"		/* Specifies users allowed to use at */
#define DENY_FILE	"at.deny"		/* Specifies users not allowed to use at */

/* Shells which can be specified through at options */

#define BOURNE_SHELL	"/bin/sh"
#define C_SHELL			"/bin/csh"
#define KORN_SHELL		"/bin/ksh"

/* --- Items below this line should rarely be changed --- */

#include "patchlevel.h"

/* Define logical values */

#define FALSE			0
#define TRUE			1

/* Maximum length of an input line */

#define MAXLINE		1024

/* Maximum sequence number which at will assign */

#define MAX_JOBNO	65535

#include <stdio.h>
#include <sys/types.h>
#include <ctype.h>
#ifdef HAS_DIRENT
#include <dirent.h> 
#else
#include <sys/dir.h>
#ifndef dirent
#define dirent direct
#endif
#endif
#include <errno.h> 
#include <fcntl.h>
#include <pwd.h>
#include <signal.h>
#include <sys/file.h>
#include <sys/param.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/timeb.h>

#ifndef HAS_RINDEX
#define rindex strrchr
#endif

#ifdef HAS_GETCWD
char *getcwd();
#else
char *getwd();
#endif

char *strcpy();
char *strncpy();
char *strcat();

void exit();

/* Handle those things that none of the include files on this system */
/* covered */

#ifndef F_OK
#define F_OK 0
#endif

#ifndef MAXPATHLEN
#define MAXPATHLEN 1024
#endif

/* Define the structure used to hold queue information */

struct queue {
	time_t qu_start;
	time_t qu_ctime;
	int qu_jobno;
	char qu_name[24];
	};
