/* permit --- check for permission to use a resource */

#include "at.h"

/* -------------------------------------------------------------------------- */

permit(username, allow_file, deny_file)

char *username;
char *allow_file;
char *deny_file;

{
	/* root always has access. */

	if (strcmp(username, "root") == 0)
		return (TRUE);

	/* If the allow file does exist, determine if the user's name */
	/* is listed there. */

	if (access(allow_file, F_OK) == 0)
		return (finduser(username, allow_file) > 0);
	
	/* The allow file didn't exist.  If the deny file doesn't exist */
	/* either, only root is permitted (through above check). */

	if (access(deny_file, F_OK) != 0)
		return (FALSE);
	
	/* The allow file doesn't exist but the deny file does.  Determine */
	/* if the user is listed in the deny file or if the file is empty. */

	return (finduser(username, deny_file) <= 0);
}

/* -------------------------------------------------------------------------- */

finduser(username, file)

char *username;
char *file;

{
	char line[64];
	int entries;
	int found = FALSE;
	FILE *listfile;

	if ((listfile = fopen(file, "r")) == NULL) {

		perror(file);
		return(-1);
	}

	for (entries = 0 ; fgets(line, 64, listfile) ; ) {

		line[strlen(line) - 1] = '\0';

		if (line[0] == '\0')
			continue;

		entries++;

		if (strcmp(username, line) == 0) {

			found = TRUE;
			break;
		}
	}

	fclose(listfile);

	if (!found)
		entries = -entries;
	
	return (entries);
}

/* -------------------------------------------------------------------------- */

whoami(owner)

char *owner;

{
	struct passwd *pw;

	uid_t uid;

	uid = getuid();

	if ((pw = getpwuid(uid)) == NULL) {

		fprintf(stderr, "you are not a valid user (no entry in /etc/passwd)\n");
		exit(1);
	}

	strcpy(owner, pw->pw_name);
}
