#define HRS		*3600
#define HALFHR	1800

struct table_def {

	char *ta_name;
	int ta_type;
	int ta_value;
	};

static struct table_def string_table[] = {

/* Months of the year */

"january",		MONTH,		0,
"jan",			MONTH,		0,
"february",		MONTH,		1,
"feb",			MONTH,		1,
"march",		MONTH,		2,
"mar",			MONTH,		2,
"april",		MONTH,		3, 
"apr",			MONTH,		3, 
"may",			MONTH,		4,
"june",			MONTH,		5,
"jun",			MONTH,		5,
"july",			MONTH,		6,
"jul",			MONTH,		6,
"august",		MONTH,		7,
"aug",			MONTH,		7,
"september",	MONTH,		8,
"sept",			MONTH,		8,
"sep",			MONTH,		8,
"october",		MONTH,		9,
"oct",			MONTH,		9,
"november",		MONTH,		10,
"nov",			MONTH,		10,
"december",		MONTH,		11,
"dec",			MONTH,		11,

/* Days of the week */

"sunday",		DAY,		0,
"sun",			DAY,		0,
"monday",		DAY,		1,
"mon",			DAY,		1,
"tuesday",		DAY,		2,
"tues",			DAY,		2,
"tue",			DAY,		2,
"wednesday",	DAY,		3,
"wed",			DAY,		3,
"thursday",		DAY,		4,
"thurs",		DAY,		4,
"thur",			DAY,		4,
"thu",			DAY,		4,
"friday",		DAY,		5,
"fri",			DAY,		5,
"saturday",		DAY,		6,
"sat",			DAY,		6,

/* The meridian names */

"am",			MERIDIAN,	AM,
"a.m.",			MERIDIAN,	AM,
"pm",			MERIDIAN,	PM,
"p.m.",			MERIDIAN,	PM,

/* Some special time names */

"midnight",		ABSHOUR,	0,
"noon",			ABSHOUR,	12,
"now",			RELDAY,		0,
"today",		RELDAY,		0,
"tomorrow",		RELDAY,		SEC_PER_DAY,
"yesterday",	RELDAY,		-1 * SEC_PER_DAY,

/* Units in terms of months */

"year",			MONUNIT,	12,
"yr",			MONUNIT,	12,
"years",		MONUNIT,	12,
"yrs",			MONUNIT,	12,
"y",			MONUNIT,	12,
"month",		MONUNIT,	1,
"months",		MONUNIT,	1,

/* Units in terms of seconds */

"fortnight",	UNIT,		2 * DAY_PER_WEEK * SEC_PER_DAY,
"fortnights",	UNIT,		2 * DAY_PER_WEEK * SEC_PER_DAY,
"week",			UNIT,		DAY_PER_WEEK * SEC_PER_DAY,
"wk",			UNIT,		DAY_PER_WEEK * SEC_PER_DAY,
"weeks",		UNIT,		DAY_PER_WEEK * SEC_PER_DAY,
"wks",			UNIT,		DAY_PER_WEEK * SEC_PER_DAY,
"w",			UNIT,		DAY_PER_WEEK * SEC_PER_DAY,
"day",			UNIT,		SEC_PER_DAY,
"days",			UNIT,		SEC_PER_DAY,
"d",			UNIT,		SEC_PER_DAY,
"hour",			UNIT,		SEC_PER_HOUR,
"hr",			UNIT,		SEC_PER_HOUR,
"hours",		UNIT,		SEC_PER_HOUR,
"hrs",			UNIT,		SEC_PER_HOUR,
"h",			UNIT,		SEC_PER_HOUR,
"minute",		UNIT,		SEC_PER_MIN,
"min",			UNIT,		SEC_PER_MIN,
"minutes",		UNIT,		SEC_PER_MIN,
"mins",			UNIT,		SEC_PER_MIN,
"m",			UNIT,		SEC_PER_MIN,
	/* This token doubles as a unit (1 second) and a relative count */
	/* (second Friday) */
"second",		SECOND,		1,
	/* These forms are units only */
"seconds",		UNIT,		1,
"sec",			UNIT,		1,
"secs",			UNIT,		1,
"s",			UNIT,		1,

/* Names for ordinal values */

"last",			ORDINAL,	-1,
"this",			ORDINAL,	0,
"first",		ORDINAL,	1,
"next",			ORDINAL,	1,
"third",		ORDINAL,	3,
"fourth",		ORDINAL,	4,
"fifth",		ORDINAL,	5,
"sixth",		ORDINAL,	6,
"seventh",		ORDINAL,	7,
"eighth",		ORDINAL,	8,
"ninth",		ORDINAL,	9,
"tenth",		ORDINAL,	10,
"eleventh",		ORDINAL,	11,
"twelfth",		ORDINAL,	12,

/* Time zone names with seconds offset from GMT */

"gmt",			STDZONE,	0, 		/* Greenwich */
"g.m.t.",		STDZONE,	0,		/* Greenwich */
"eet",			STDZONE,	0,		/* European Eastern Time */
"e.e.t.",		STDZONE,	0,		/* European Eastern Time */
"nst",			STDZONE,	3 HRS + HALFHR, /* Newfoundland */
"n.s.t.",		STDZONE,	3 HRS + HALFHR, /* Newfoundland */
"ast",			STDZONE,	4 HRS,	/* Atlantic */
"a.s.t.",		STDZONE,	4 HRS,	/* Atlantic */
"adt",			DSTZONE,	4 HRS,	/* Atlantic DST */
"a.d.t.",		DSTZONE,	4 HRS,	/* Atlantic DST */
"est",			STDZONE,	5 HRS,	/* Eastern */
"e.s.t.",		STDZONE,	5 HRS,	/* Eastern */
"edt",			DSTZONE,	5 HRS,	/* Eastern DST*/
"e.d.t.",		DSTZONE,	5 HRS,	/* Eastern DST*/
"cst",			STDZONE,	6 HRS,	/* Central */
"c.s.t.",		STDZONE,	6 HRS,	/* Central */
"cdt",			DSTZONE,	6 HRS,	/* Central DST */
"c.d.t.",		DSTZONE,	6 HRS,	/* Central DST */
"mst",			STDZONE,	7 HRS,	/* Mountain */
"m.s.t.",		STDZONE,	7 HRS,	/* Mountain */
"mdt",			DSTZONE,	7 HRS,	/* Mountain DST */
"m.d.t.",		DSTZONE,	7 HRS,	/* Mountain DST */
"pst",			STDZONE,	8 HRS,	/* Pacific */
"p.s.t.",		STDZONE,	8 HRS,	/* Pacific */
"pdt",			DSTZONE,	8 HRS,	/* Pacific DST */
"p.d.t.",		DSTZONE,	8 HRS,	/* Pacific DST */
"yst",			STDZONE,	9 HRS,	/* Yukon */
"y.s.t.",		STDZONE,	9 HRS,	/* Yukon */
"ydt",			DSTZONE,	9 HRS,	/* Yukon DST */
"y.d.t.",		DSTZONE,	9 HRS,	/* Yukon DST */
"hst",			STDZONE,	10 HRS,	/* Hawaii */
"h.s.t.",		STDZONE,	10 HRS,	/* Hawaii */
"hdt",			DSTZONE,	10 HRS,	/* Hawaii DST */
"h.d.t.",		DSTZONE,	10 HRS,	/* Hawaii DST */
"bst",			DSTZONE,	0,		/* British Summer Time */
"b.s.t.",		DSTZONE,	0,		/* British Summer Time */
"eet",			STDZONE,	0,		/* European Eastern Time */
"e.e.t.",		STDZONE,	0,		/* European Eastern Time */
"eest",			DSTZONE,	0,		/* European Eastern Summer Time */
"e.e.s.t.",		DSTZONE,	0,		/* European Eastern Summer Time */
"met",			STDZONE,	-1 HRS,	/* Middle European Time */
"m.e.t.",		STDZONE,	-1 HRS,	/* Middle European Time */
"mest",			DSTZONE,	-1 HRS,	/* Middle European Summer Time */
"m.e.s.t.",		DSTZONE,	-1 HRS,	/* Middle European Summer Time */
"wet",			STDZONE,	-2 HRS,	/* Western European Time */
"w.e.t.",		STDZONE,	-2 HRS,	/* Western European Time */
"west",			DSTZONE,	-2 HRS,	/* Western European Summer Time */
"w.e.s.t.",		DSTZONE,	-2 HRS,	/* Western European Summer Time */
"jst",			STDZONE,	-9 HRS,	/* Japan Standard Time */
"j.s.t.",		STDZONE,	-9 HRS,	/* Japan Standard Time */
"aest",			STDZONE,	-10 HRS,	/* Australian Eastern Time */
"a.e.s.t.",		STDZONE,	-10 HRS,	/* Australian Eastern Time */
"aesst",		DSTZONE,	-10 HRS,	/* Australian Eastern Summer Time */
"a.e.s.s.t.",	DSTZONE,	-10 HRS,	/* Australian Eastern Summer Time */
"acst",			STDZONE,	-(9 HRS + HALFHR),	/* Australian Central Time */
"a.c.s.t.",		STDZONE,	-(9 HRS + HALFHR),	/* Australian Central Time */
"acsst",		DSTZONE,	-(9 HRS + HALFHR),
										/* Australian Central Summer Time */
"a.c.s.s.t."  ,	DSTZONE,	-(9 HRS + HALFHR),
										/* Australian Central Summer Time */
"awst",			STDZONE,	-8 HRS,		/* Australian Western Time */
"a.w.s.t.",		STDZONE,	-8 HRS,		/* Australian Western Time */
};
